@@ -1,7 +1,3 @@
-
-import pyhttpx
-from loguru import logger
-
 from .base import BaseCracker
 
 import warnings
