@@ -29,12 +29,12 @@ class HcaptchaCracker(BaseCracker):
     """
     
     # 必传参数
-    must_check_params = ["sitekey"]
+    must_check_params = ["sitekey", "referer"]
     # 默认可选参数
     option_params = {
         "mode": "picture",   # 验证模式, 默认图片验证, 可选 question 题库验证
-        "referer": "https://newassets.hcaptcha.com/",
         "rqdata": "",
-        "user_agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/106.0.0.0 Safari/537.36",
+        "domain": "hcaptcha.com",
+        "device": "chrome",
     }
 
